@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -37,6 +37,9 @@ _messages = {
     "E116": QCoreApplication.translate(
         "pycodestyle",
         "unexpected indentation (comment)"),
+    "E117": QCoreApplication.translate(
+        "pycodestyle",
+        "over-indented"),
     "E121": QCoreApplication.translate(
         "pycodestyle",
         "continuation line indentation is not a multiple of four"),
@@ -122,6 +125,9 @@ _messages = {
     "E251": QCoreApplication.translate(
         "pycodestyle",
         "unexpected spaces around keyword / parameter equals"),
+    "E252": QCoreApplication.translate(
+        "pycodestyle",
+        "missing whitespace around parameter equals"),
     "E261": QCoreApplication.translate(
         "pycodestyle",
         "at least two spaces before inline comment"),
@@ -160,23 +166,29 @@ _messages = {
         "blank line contains whitespace"),
     "E301": QCoreApplication.translate(
         "pycodestyle",
-        "expected 1 blank line, found 0"),
+        "expected {0} blank lines, found {1}"),
     "E302": QCoreApplication.translate(
         "pycodestyle",
-        "expected 2 blank lines, found {0}"),
+        "expected {0} blank lines, found {1}"),
     "E303": QCoreApplication.translate(
         "pycodestyle",
-        "too many blank lines ({0})"),
+        "too many blank lines ({0}), expected {1}"),
     "E304": QCoreApplication.translate(
         "pycodestyle",
         "blank lines found after function decorator"),
     "E305": QCoreApplication.translate(
         "pycodestyle",
-        "expected 2 blank lines after class or function definition,"
-        " found {0}"),
+        "expected {0} blank lines after class or function definition,"
+        " found {1}"),
     "E306": QCoreApplication.translate(
         "pycodestyle",
-        "expected 1 blank line before a nested definition, found 0"),
+        "expected {0} blank lines before a nested definition, found {1}"),
+    "E307": QCoreApplication.translate(
+        "pycodestyle",
+        "too many blank lines ({0}) before a nested definition, expected {1}"),
+    "E308": QCoreApplication.translate(
+        "pycodestyle",
+        "too many blank lines ({0})"),
     "W391": QCoreApplication.translate(
         "pycodestyle",
         "blank line at end of file"),
@@ -195,6 +207,12 @@ _messages = {
     "W503": QCoreApplication.translate(
         "pycodestyle",
         "line break before binary operator"),
+    "W504": QCoreApplication.translate(
+        "pycodestyle",
+        "line break after binary operator"),
+    "W505": QCoreApplication.translate(
+        "pycodestyle",
+        "doc line too long ({0} > {1} characters)"),
     "W601": QCoreApplication.translate(
         "pycodestyle",
         ".has_key() is deprecated, use 'in'"),
@@ -207,6 +225,12 @@ _messages = {
     "W604": QCoreApplication.translate(
         "pycodestyle",
         "backticks are deprecated, use 'repr()'"),
+    "W605": QCoreApplication.translate(
+        "pycodestyle",
+        "invalid escape sequence '\\{0}'"),
+    "W606": QCoreApplication.translate(
+        "pycodestyle",
+        "'async' and 'await' are reserved keywords starting with Python 3.7"),
     "E701": QCoreApplication.translate(
         "pycodestyle",
         "multiple statements on one line (colon)"),
@@ -711,9 +735,6 @@ _messages = {
     "FE261": QCoreApplication.translate(
         'CodeStyleFixer',
         "Whitespace around comment sign corrected."),
-    "FE301": QCoreApplication.translate(
-        'CodeStyleFixer',
-        "One blank line inserted."),
     
     "FE302+": lambda n=1: translate(
         'CodeStyleFixer',
@@ -778,10 +799,16 @@ _messages_sample_args = {
     "E231": [",;:"],
     "E241": [",;:"],
     "E242": [",;:"],
-    "E302": [1],
-    "E303": [3],
-    "E305": [1],
+    "E301": [1, 0],
+    "E302": [2, 1],
+    "E303": [3, 2],
+    "E305": [2, 1],
+    "E306": [1, 0],
+    "E307": [3, 1],
+    "E308": [3],
     "E501": [85, 79],
+    "W505": [80, 72],
+    "E605": ["A"],
     "E711": ["None", "'if cond is None:'"],
     "E712": ["True", "'if cond is True:' or 'if cond:'"],
     "E741": ["l"],
@@ -851,3 +878,6 @@ def getTranslatedMessage(message):
         return QCoreApplication.translate(
             "CodeStyleFixer", " no message defined for code '{0}'")\
             .format(message)
+
+#
+# eflag: noqa = M201
