@@ -72,7 +72,10 @@ def exeDisplayDataList():
     })
     
     # 2. Qt Help Generator
-    exe = os.path.join(Utilities.getQtBinariesPath(), 'qhelpgenerator')
+    exe = os.path.join(
+        Utilities.getQtBinariesPath(),
+        Utilities.generateQtToolName('qhelpgenerator')
+    )
     if Utilities.isWindowsPlatform():
         exe += '.exe'
     dataList.append({
@@ -88,20 +91,25 @@ def exeDisplayDataList():
     })
     
     # 3. Qt Collection Generator
-    exe = os.path.join(Utilities.getQtBinariesPath(), 'qcollectiongenerator')
+    exe = os.path.join(
+        Utilities.getQtBinariesPath(),
+        Utilities.generateQtToolName('qcollectiongenerator')
+    )
     if Utilities.isWindowsPlatform():
         exe += '.exe'
-    dataList.append({
-        "programEntry": True,
-        "header": QCoreApplication.translate(
-            "EricdocPlugin", "Qt Help Tools"),
-        "exe": exe,
-        "versionCommand": '-v',
-        "versionStartsWith": 'Qt',
-        "versionPosition": -1,
-        "version": "",
-        "versionCleanup": (0, -1),
-    })
+    if Utilities.isExecutable(exe):
+        # assume Qt 5.,12 if it is missing
+        dataList.append({
+            "programEntry": True,
+            "header": QCoreApplication.translate(
+                "EricdocPlugin", "Qt Help Tools"),
+            "exe": exe,
+            "versionCommand": '-v',
+            "versionStartsWith": 'Qt',
+            "versionPosition": -1,
+            "version": "",
+            "versionCleanup": (0, -1),
+        })
     
     return dataList
 
