@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,7 +11,7 @@ from __future__ import unicode_literals
 
 import os
 
-from PyQt5.QtCore import QObject, QCoreApplication
+from PyQt5.QtCore import QObject, QCoreApplication, QByteArray
 
 from E5Gui.E5Application import e5App
 
@@ -143,12 +143,49 @@ def prepareUninstall():
     if not e5App().getObject("PluginManager").isPluginLoaded(
             "PluginVcsMercurial"):
         Preferences.Prefs.settings.remove("Mercurial")
+
+
+def clearPrivateData():
+    """
+    Module function to clear the private data of the plug-in.
+    """
+    for key in ["RepositoryUrlHistory"]:
+        VcsMercurialPlugin.setPreferences(key, [])
     
 
 class VcsMercurialPlugin(QObject):
     """
     Class implementing the Mercurial version control plugin.
     """
+    MercurialDefaults = {
+        "StopLogOnCopy": True,  # used in log browser
+        "LogLimit": 20,
+        "CommitMessages": 20,
+        "Commits": [],
+        "CommitAuthorsLimit": 20,
+        "CommitAuthors": [],
+        "PullUpdate": False,
+        "PreferUnbundle": False,
+        "ServerPort": 8000,
+        "ServerStyle": "",
+        "CleanupPatterns": "*.orig *.rej *~",
+        "CreateBackup": False,
+        "InternalMerge": False,
+        "Encoding": "utf-8",
+        "EncodingMode": "strict",
+        "ConsiderHidden": False,
+        "LogMessageColumnWidth": 30,
+        "LogBrowserGeometry": QByteArray(),
+        "LogBrowserSplitterStates": [QByteArray(), QByteArray(),
+                                     QByteArray()],
+        # mainSplitter, detailsSplitter, diffSplitter
+        "StatusDialogGeometry": QByteArray(),
+        "StatusDialogSplitterState": QByteArray(),
+        "MqStatusDialogGeometry": QByteArray(),
+        "MqStatusDialogSplitterState": QByteArray(),
+        "RepositoryUrlHistory": [],
+    }
+    
     def __init__(self, ui):
         """
         Constructor
@@ -158,26 +195,6 @@ class VcsMercurialPlugin(QObject):
         super(VcsMercurialPlugin, self).__init__(ui)
         self.__ui = ui
         
-        self.__mercurialDefaults = {
-            "StopLogOnCopy": True,  # used in log browser
-            "UseLogBrowser": True,
-            "LogLimit": 20,
-            "CommitMessages": 20,
-            "Commits": [],
-            "CommitAuthorsLimit": 20,
-            "CommitAuthors": [],
-            "PullUpdate": False,
-            "PreferUnbundle": False,
-            "ServerPort": 8000,
-            "ServerStyle": "",
-            "CleanupPatterns": "*.orig *.rej *~",
-            "CreateBackup": False,
-            "InternalMerge": False,
-            "Encoding": "utf-8",
-            "EncodingMode": "strict",
-            "ConsiderHidden": False,
-        }
-        
         from VcsPlugins.vcsMercurial.ProjectHelper import HgProjectHelper
         self.__projectHelperObject = HgProjectHelper(None, None)
         try:
@@ -240,32 +257,49 @@ class VcsMercurialPlugin(QObject):
         tb.setVisible(True)
         tb.setEnabled(True)
     
-    def getPreferences(self, key):
+    @classmethod
+    def getPreferences(cls, key):
         """
-        Public method to retrieve the various settings.
+        Class method to retrieve the various settings.
         
         @param key the key of the value to get
         @return the requested setting
         """
-        if key in ["StopLogOnCopy", "UseLogBrowser", "PullUpdate",
-                   "PreferUnbundle", "CreateBackup", "InternalMerge",
-                   "ConsiderHidden"]:
+        if key in ["StopLogOnCopy", "PullUpdate", "PreferUnbundle",
+                   "CreateBackup", "InternalMerge", "ConsiderHidden"]:
             return Preferences.toBool(Preferences.Prefs.settings.value(
-                "Mercurial/" + key, self.__mercurialDefaults[key]))
+                "Mercurial/" + key, cls.MercurialDefaults[key]))
         elif key in ["LogLimit", "CommitMessages", "CommitAuthorsLimit",
-                     "ServerPort"]:
+                     "ServerPort", "LogMessageColumnWidth"]:
             return int(Preferences.Prefs.settings.value(
-                "Mercurial/" + key, self.__mercurialDefaults[key]))
-        elif key in ["Commits", "CommitAuthors"]:
+                "Mercurial/" + key, cls.MercurialDefaults[key]))
+        elif key in ["Commits", "CommitAuthors", "RepositoryUrlHistory"]:
             return Preferences.toList(Preferences.Prefs.settings.value(
-                "Mercurial/" + key))
+                "Mercurial/" + key, cls.MercurialDefaults[key]))
+        elif key in ["LogBrowserGeometry", "StatusDialogGeometry",
+                     "StatusDialogSplitterState", "MqStatusDialogGeometry",
+                     "MqStatusDialogSplitterState"]:
+            # QByteArray values
+            v = Preferences.Prefs.settings.value("Mercurial/" + key)
+            if v is not None:
+                return v
+            else:
+                return cls.MercurialDefaults[key]
+        elif key in ["LogBrowserSplitterStates"]:
+            # list of QByteArray values
+            states = Preferences.Prefs.settings.value("Mercurial/" + key)
+            if states is not None:
+                return states
+            else:
+                return cls.MercurialDefaults[key]
         else:
             return Preferences.Prefs.settings.value(
-                "Mercurial/" + key, self.__mercurialDefaults[key])
+                "Mercurial/" + key, cls.MercurialDefaults[key])
     
-    def setPreferences(self, key, value):
+    @classmethod
+    def setPreferences(cls, key, value):
         """
-        Public method to store the various settings.
+        Class method to store the various settings.
         
         @param key the key of the setting to be set
         @param value the value to be set
@@ -280,11 +314,11 @@ class VcsMercurialPlugin(QObject):
         """
         args = []
         if self.getPreferences("Encoding") != \
-                self.__mercurialDefaults["Encoding"]:
+                self.MercurialDefaults["Encoding"]:
             args.append("--encoding")
             args.append(self.getPreferences("Encoding"))
         if self.getPreferences("EncodingMode") != \
-                self.__mercurialDefaults["EncodingMode"]:
+                self.MercurialDefaults["EncodingMode"]:
             args.append("--encodingmode")
             args.append(self.getPreferences("EncodingMode"))
         if self.getPreferences("ConsiderHidden"):
