@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -16,12 +16,14 @@ from E5Gui.E5Application import e5App
 from E5Gui.E5Action import E5Action
 from E5Gui import E5MessageBox
 
+import UI.Info
+
 # Start-Of-Header
 name = "E5MessageBox Wizard Plugin"
 author = "Detlev Offenbach <detlev@die-offenbachs.de>"
 autoactivate = True
 deactivateable = True
-version = "6.2.0"
+version = UI.Info.VersionOnly
 className = "E5MessageBoxWizard"
 packageName = "__core__"
 shortDescription = "Show the E5MessageBox wizard."
@@ -121,10 +123,10 @@ class E5MessageBoxWizard(QObject):
         editor = e5App().getObject("ViewManager").activeWindow()
         
         if editor is None:
-                E5MessageBox.critical(
-                    self.__ui,
-                    self.tr('No current editor'),
-                    self.tr('Please open or create a file first.'))
+            E5MessageBox.critical(
+                self.__ui,
+                self.tr('No current editor'),
+                self.tr('Please open or create a file first.'))
         else:
             code, ok = self.__callForm(editor)
             if ok:
