@@ -77,12 +77,23 @@ class GitSubmoduleAddDialog(QDialog, Ui_GitSubmoduleAddDialog):
         @param txt current text of the combo box
         @type str
         """
-        url = QUrl.fromUserInput(txt)
-        enable = url.isValid() and url.scheme() in ConfigGitSchemes
-        self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(enable)
+        enable = False
+        vcsUrlEnable = False
         
-        self.submoduleUrlButton.setEnabled(url.scheme() == "file" or
-                                           len(txt) == 0)
+        if txt:
+            url = QUrl.fromUserInput(txt)
+            if url.isValid():
+                if url.scheme() in ConfigGitSchemes:
+                    enable = True
+                    vcsUrlEnable = url.scheme() == "file"
+            elif ':' in txt:
+                # assume scp like repository URL
+                enable = True
+        else:
+            vcsUrlEnable = True
+        
+        self.buttonBox.button(QDialogButtonBox.Ok).setEnabled(enable)
+        self.submoduleUrlButton.setEnabled(vcsUrlEnable)
     
     @pyqtSlot()
     def on_submoduleUrlButton_clicked(self):
@@ -136,19 +147,12 @@ class GitSubmoduleAddDialog(QDialog, Ui_GitSubmoduleAddDialog):
         """
         self.__saveHistory()
         
-        url = QUrl.fromUserInput(
-            self.submoduleUrlCombo.currentText().replace("\\", "/"))
         path = self.submoduleDirEdit.text()
         if path:
             path = self.__getRelativePath(path)
         
-        try:
-            formattingOptions = QUrl.FormattingOptions(QUrl.None_)
-        except AttributeError:
-            # for PyQt < 5.6.0
-            formattingOptions = QUrl.FormattingOptions(0)
         return (
-            url.toString(formattingOptions),
+            self.submoduleUrlCombo.currentText().replace("\\", "/"),
             self.branchEdit.text(),
             self.nameEdit.text(),
             path,
