@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -38,14 +38,21 @@ class EmailPage(ConfigurationPageBase, Ui_EmailPage):
         
         self.__helpDialog = None
         
+        pipPackages = [
+            "google-api-python-client",
+            "google-auth-oauthlib",
+        ]
+        self.__pipCommand = "pip install --upgrade {0}".format(
+            " ".join(pipPackages))
+        
         # set initial values
         try:
             import googleapiclient      # __IGNORE_WARNING__
             self.googleMailCheckBox.setChecked(
                 Preferences.getUser("UseGoogleMailOAuth2"))
             
-            from E5Network.E5GoogleMail import isCredentialsFileAvailable
-            if not isCredentialsFileAvailable():
+            from E5Network.E5GoogleMail import isClientSecretFileAvailable
+            if not isClientSecretFileAvailable():
                 # credentials file is not installed
                 self.googleMailCheckBox.setChecked(False)
                 self.googleMailCheckBox.setEnabled(False)
@@ -59,8 +66,8 @@ class EmailPage(ConfigurationPageBase, Ui_EmailPage):
             self.googleMailCheckBox.setEnabled(False)
             self.googleMailInfoLabel.setText(self.tr(
                 "<p>The Google Mail Client API is not installed."
-                " Use <code>pip install --upgrade google-api-python-client"
-                "</code> to install it.</p>"))
+                " Use <code>{0}</code> to install it.</p>")
+                .format(self.__pipCommand))
             self.googleHelpButton.setEnabled(False)
             Preferences.setUser("UseGoogleMailOAuth2", False)
         
@@ -283,10 +290,10 @@ class EmailPage(ConfigurationPageBase, Ui_EmailPage):
                 from E5Network.E5GoogleMail import GoogleMailHelp
                 helpStr = GoogleMailHelp()
             except ImportError:
-                helpStr = self.tr(
-                    "<p>The Google Mail Client API is not installed."
-                    " Use <code>pip install --upgrade google-api-python-client"
-                    "</code> to install it.</p>")
+                    helpStr = self.tr(
+                        "<p>The Google Mail Client API is not installed."
+                        " Use <code>{0}</code> to install it.</p>"
+                    ).format(self.__pipCommand)
             
             from E5Gui.E5SimpleHelpDialog import E5SimpleHelpDialog
             self.__helpDialog = E5SimpleHelpDialog(
