@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -60,6 +60,8 @@ class ProjectPage(ConfigurationPageBase, Ui_ProjectPage):
             Preferences.getProject("TasksProjectAutoSave"))
         self.rescanTasksCheckBox.setChecked(
             Preferences.getProject("TasksProjectRescanOnOpen"))
+        self.restartShellCheckBox.setChecked(
+            Preferences.getProject("RestartShellForProject"))
         
     def save(self):
         """
@@ -113,6 +115,9 @@ class ProjectPage(ConfigurationPageBase, Ui_ProjectPage):
         Preferences.setProject(
             "TasksProjectRescanOnOpen",
             self.rescanTasksCheckBox.isChecked())
+        Preferences.setProject(
+            "RestartShellForProject",
+            self.restartShellCheckBox.isChecked())
     
 
 def create(dlg):
