@@ -84,6 +84,12 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
         except KeyError:
             self.autoplayMediaCheckBox.setEnabled(False)
             self.webRtcPublicOnlyCheckBox.setEnabled(False)
+        try:
+            # Qt 5.12
+            self.dnsPrefetchCheckBox.setChecked(
+                Preferences.getWebBrowser("DnsPrefetchEnabled"))
+        except KeyError:
+            self.dnsPrefetchCheckBox.setEnabled(False)
         
         self.javaScriptGroup.setChecked(
             Preferences.getWebBrowser("JavaScriptEnabled"))
@@ -281,6 +287,11 @@ class WebBrowserPage(ConfigurationPageBase, Ui_WebBrowserPage):
                 "WebRTCPublicInterfacesOnly",
                 self.webRtcPublicOnlyCheckBox.isChecked())
         
+        if self.dnsPrefetchCheckBox.isEnabled():
+            Preferences.setWebBrowser(
+                "DnsPrefetchEnabled",
+                self.dnsPrefetchCheckBox.isChecked())
+        
         Preferences.setWebBrowser(
             "JavaScriptEnabled",
             self.javaScriptGroup.isChecked())
