@@ -215,8 +215,25 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
             Utilities.isWindowsPlatform() and "rbrcc.exe" or "rbrcc",
             '-version', 'Ruby Resource Compiler', -1)
         
-        # 5. do the CORBA and Protobuf programs
-        # 5a. omniORB
+        # 5. do the Conda program(s)
+        exe = Preferences.getConda("CondaExecutable")
+        if not exe:
+            exe = "conda"
+            if Utilities.isWindowsPlatform():
+                exe += ".exe"
+        self.__createProgramEntry(
+            self.tr("conda Manager"), exe, '--version', 'conda', -1)
+        
+        # 6. do the pip program(s)
+        virtualenvManager = e5App().getObject("VirtualEnvManager")
+        for venvName in virtualenvManager.getVirtualenvNames():
+            interpreter = virtualenvManager.getVirtualenvInterpreter(venvName)
+            self.__createProgramEntry(
+                self.tr("PyPI Package Management"), interpreter, '--version',
+                'pip', 1, exeModule=["-m", "pip"])
+        
+        # 7. do the CORBA and Protobuf programs
+        # 7a. omniORB
         exe = Preferences.getCorba("omniidl")
         if not exe:
             exe = "omniidl"
@@ -224,7 +241,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                 exe += ".exe"
         self.__createProgramEntry(
             self.tr("CORBA IDL Compiler"), exe, '-V', 'omniidl', -1)
-        # 5b. protobuf
+        # 7b. protobuf
         exe = Preferences.getProtobuf("protoc")
         if not exe:
             exe = "protoc"
@@ -232,7 +249,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                 exe += ".exe"
         self.__createProgramEntry(
             self.tr("Protobuf Compiler"), exe, '--version', 'libprotoc', -1)
-        # 5c. grpc
+        # 7c. grpc
         exe = Preferences.getProtobuf("grpcPython")
         if not exe:
             exe = sys.executable
@@ -240,7 +257,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
             self.tr("gRPC Compiler"), exe, '--version', 'libprotoc', -1,
             exeModule=['-m', 'grpc_tools.protoc'])
         
-        # 6. do the spell checking entry
+        # 8. do the spell checking entry
         try:
             import enchant
             try:
@@ -257,7 +274,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         self.__createEntry(
             self.tr("Spell Checker - PyEnchant"), text, version)
         
-        # 7. do the pygments entry
+        # 9. do the pygments entry
         try:
             import pygments
             try:
@@ -274,7 +291,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         self.__createEntry(
             self.tr("Source Highlighter - Pygments"), text, version)
         
-        # do the plugin related programs
+        # 10. do the plugin related programs
         pm = e5App().getObject("PluginManager")
         for info in pm.getPluginExeDisplayData():
             if info["programEntry"]:
@@ -340,6 +357,7 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
         font = itm.font(0)
         font.setBold(True)
         itm.setFont(0, font)
+        rememberedExe = exe
         if not exe:
             itm.setText(1, self.tr("(not configured)"))
         else:
@@ -367,7 +385,8 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                                      'replace')
                         if exeModule and exeModule[0] == "-m" and \
                             ("ImportError:" in output or
-                             "ModuleNotFoundError:" in output):
+                             "ModuleNotFoundError:" in output or
+                             proc.exitCode() != 0):
                             version = self.tr("(module not found)")
                         else:
                             if versionRe is None:
@@ -398,7 +417,12 @@ class ProgramsDialog(QDialog, Ui_ProgramsDialog):
                     QTreeWidgetItem(itm, [exe, version])
                 itm.setExpanded(True)
             else:
-                itm.setText(1, self.tr("(not found)"))
+                if itm.childCount() == 0:
+                    itm.setText(1, self.tr("(not found)"))
+                else:
+                    QTreeWidgetItem(itm, [rememberedExe,
+                                          self.tr("(not found)")])
+                    itm.setExpanded(True)
         QApplication.processEvents()
         self.programsList.header().resizeSections(QHeaderView.ResizeToContents)
         self.programsList.header().setStretchLastSection(True)
