@@ -84,7 +84,8 @@ class DebuggerPropertiesDialog(QDialog, Ui_DebuggerPropertiesDialog):
         self.venvComboBox.setCurrentIndex(venvIndex)
         if self.project.debugProperties["DEBUGCLIENT"]:
             self.debugClientPicker.setText(
-                self.project.debugProperties["DEBUGCLIENT"])
+                self.project.debugProperties["DEBUGCLIENT"],
+                toNative=False)
         else:
             if self.project.pdata["PROGLANGUAGE"] in ["Python", "Python2",
                                                       "Python3"]:
@@ -93,7 +94,7 @@ class DebuggerPropertiesDialog(QDialog, Ui_DebuggerPropertiesDialog):
                     "DebugClients", "Python", "DebugClient.py")
             else:
                 debugClient = ""
-            self.debugClientPicker.setText(debugClient)
+            self.debugClientPicker.setText(debugClient, toNative=False)
         self.debugEnvironmentOverrideCheckBox.setChecked(
             self.project.debugProperties["ENVIRONMENTOVERRIDE"])
         self.debugEnvironmentEdit.setText(
@@ -141,7 +142,7 @@ class DebuggerPropertiesDialog(QDialog, Ui_DebuggerPropertiesDialog):
             self.venvComboBox.currentText()
         
         self.project.debugProperties["DEBUGCLIENT"] = \
-            self.debugClientPicker.text()
+            self.debugClientPicker.text(toNative=False)
         if not self.project.debugProperties["DEBUGCLIENT"]:
             if self.project.pdata["PROGLANGUAGE"] in ["Python", "Python2",
                                                       "Python3"]:
@@ -184,7 +185,7 @@ class DebuggerPropertiesDialog(QDialog, Ui_DebuggerPropertiesDialog):
         """
         Private method to save the path picker histories.
         """
-        debugClient = self.debugClientPicker.text()
+        debugClient = self.debugClientPicker.text(toNative=False)
         debugClientsHistory = self.debugClientPicker.getPathItems()
         if debugClient not in debugClientsHistory:
             debugClientsHistory.insert(0, debugClient)
