@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2004 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2004 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -1621,6 +1621,21 @@ class QsciScintillaCompat(QsciScintilla):
             else:
                 return string.encode("latin-1")
     
+    ###########################################################################
+    ## methods to implement workarounds for broken things
+    ###########################################################################
+    
+    if QSCINTILLA_VERSION() == 0x020B00:
+        def insert(self, txt):
+            """
+            Public method to insert text at the cursor position.
+            
+            @param txt text to be inserted
+            @type str
+            """
+            line, col = self.getCursorPosition()
+            self.insertAt(txt, line, col)
+    
     ###########################################################################
     ## methods below have been added to QScintilla starting with version 2.5
     ###########################################################################
