@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2012 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2012 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -9,14 +9,15 @@ Module implementing a grabber widget for a rectangular snapshot region.
 
 from __future__ import unicode_literals
 
-from PyQt5.QtCore import pyqtSignal, Qt, QRect, QPoint, QTimer, QLocale, \
-    qVersion
+from PyQt5.QtCore import pyqtSignal, Qt, QRect, QPoint, QTimer, QLocale
 from PyQt5.QtGui import QPixmap, QColor, QRegion, QPainter, QPalette, \
     QPaintEngine, QPen, QBrush
 from PyQt5.QtWidgets import QWidget, QApplication, QToolTip
 
+from Globals import qVersionTuple
 
-def drawRect(painter, rect, outline, fill=QColor()):
+
+def drawRect(painter, rect, outline, fill=None):
     """
     Module function to draw a rectangle with the given parameters.
     
@@ -33,7 +34,7 @@ def drawRect(painter, rect, outline, fill=QColor()):
     painter.setPen(Qt.NoPen)
     painter.setBrush(outline)
     painter.drawRect(rect)
-    if fill.isValid():
+    if fill is not None and fill.isValid():
         painter.setClipping(False)
         painter.setBrush(fill)
         painter.drawRect(rect.adjusted(1, 1, -1, -1))
@@ -114,7 +115,7 @@ class SnapshotRegionGrabber(QWidget):
         self.__desktop = QApplication.desktop()
         x = self.__desktop.x()
         y = self.__desktop.y()
-        if qVersion() >= "5.0.0":
+        if qVersionTuple() >= (5, 0, 0):
             self.__pixmap = QApplication.screens()[0].grabWindow(
                 self.__desktop.winId(), x, y,
                 self.__desktop.width(), self.__desktop.height())
@@ -414,8 +415,10 @@ class SnapshotRegionGrabber(QWidget):
         self.__BLHandle.moveBottomLeft(r.bottomLeft())
         self.__BRHandle.moveBottomRight(r.bottomRight())
         
-        self.__LHandle.moveTopLeft(QPoint(r.x(), r.y() + r.height() // 2 - s2))
-        self.__THandle.moveTopLeft(QPoint(r.x() + r.width() // 2 - s2, r.y()))
+        self.__LHandle.moveTopLeft(
+            QPoint(r.x(), r.y() + r.height() // 2 - s2))
+        self.__THandle.moveTopLeft(
+            QPoint(r.x() + r.width() // 2 - s2, r.y()))
         self.__RHandle.moveTopRight(
             QPoint(r.right(), r.y() + r.height() // 2 - s2))
         self.__BHandle.moveBottomLeft(
