@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -11,6 +11,7 @@ from __future__ import unicode_literals
 
 try:  # Only for Py2
     import StringIO as io   # __IGNORE_EXCEPTION__
+    str = unicode
 except (ImportError, NameError):
     import io       # __IGNORE_WARNING__
 
@@ -51,17 +52,28 @@ class PreviewerHTML(QWidget):
         self.titleLabel.setTextInteractionFlags(Qt.NoTextInteraction)
         self.__layout.addWidget(self.titleLabel)
         
+        self.__previewAvailable = True
+        
         try:
             from PyQt5.QtWebEngineWidgets import QWebEngineView
             self.previewView = QWebEngineView(self)
             self.previewView.page().linkHovered.connect(self.__showLink)
             self.__usesWebKit = False
         except ImportError:
-            from PyQt5.QtWebKitWidgets import QWebPage, QWebView
-            self.previewView = QWebView(self)
-            self.previewView.page().setLinkDelegationPolicy(
-                QWebPage.DelegateAllLinks)
-            self.__usesWebKit = True
+            try:
+                from PyQt5.QtWebKitWidgets import QWebPage, QWebView
+                self.previewView = QWebView(self)
+                self.previewView.page().setLinkDelegationPolicy(
+                    QWebPage.DelegateAllLinks)
+                self.__usesWebKit = True
+            except ImportError:
+                self.__previewAvailable = False
+                self.titleLabel.setText(self.tr(
+                    "<b>HTML Preview is not available!<br/>"
+                    "Install QtWebEngine or QtWebKit.</b>"))
+                self.titleLabel.setAlignment(Qt.AlignHCenter)
+                self.__layout.addStretch()
+                return
         
         sizePolicy = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Expanding)
         sizePolicy.setHorizontalStretch(0)
@@ -110,7 +122,8 @@ class PreviewerHTML(QWidget):
         """
         Public method to perform shutdown actions.
         """
-        self.__processingThread.wait()
+        if self.__previewAvailable:
+            self.__processingThread.wait()
     
     @pyqtSlot(bool)
     def on_jsCheckBox_clicked(self, checked):
@@ -161,6 +174,9 @@ class PreviewerHTML(QWidget):
         
         @param editor editor to be processed (Editor)
         """
+        if not self.__previewAvailable:
+            return
+        
         if editor is None:
             editor = self.__previewedEditor
         else:
@@ -329,9 +345,10 @@ class PreviewerHTML(QWidget):
         """
         Private slot handling the clicking of a link.
         
-        @param url url of the clicked link (QUrl)
+        @param url URL of the clicked link
+        @type QUrl
         """
-        e5App().getObject("UserInterface").launchHelpViewer(url.toString())
+        e5App().getObject("UserInterface").launchHelpViewer(url)
     
     def __execJavaScript(self, script):
         """
@@ -643,6 +660,7 @@ class PreviewProcessingThread(QThread):
         
         try:
             import docutils.core    # __IGNORE_EXCEPTION__
+            import docutils.utils   # __IGNORE_EXCEPTION__
         except ImportError:
             return self.tr(
                 """<p>ReStructuredText preview requires the"""
@@ -654,8 +672,15 @@ class PreviewProcessingThread(QThread):
         # redirect sys.stderr because we are not interested in it here
         origStderr = sys.stderr
         sys.stderr = io.StringIO()
-        html = docutils.core.publish_string(
-            text, writer_name=htmlFormat.lower()).decode("utf-8")
+        try:
+            html = docutils.core.publish_string(
+                text, writer_name=htmlFormat.lower()).decode("utf-8")
+        except docutils.utils.SystemMessage as err:
+            errStr = str(err).split(":")[-1].replace("\n", "<br/>")
+            return self.tr(
+                """<p>Docutils returned an error:</p><p>{0}</p>"""
+            ).format(errStr)
+        
         sys.stderr = origStderr
         return html
     
