@@ -31,11 +31,13 @@ SUPPORTED_TYPES = [ClassBrowsers.PY_SOURCE, ClassBrowsers.PTL_SOURCE]
 _getnext = re.compile(
     r"""
     (?P<String>
-       \""" [^"\\]* (?:
+        \# .*? $   # ignore everything in comments
+    |
+        \""" [^"\\]* (?:
                         (?: \\. | "(?!"") )
                         [^"\\]*
                     )*
-       \"""
+        \"""
 
     |   ''' [^'\\]* (?:
                         (?: \\. | '(?!'') )
