@@ -29,6 +29,7 @@ from WebBrowser.WebBrowserWindow import WebBrowserWindow
 from .NetworkUrlInterceptor import NetworkUrlInterceptor
 from ..Tools.WebBrowserTools import readAllFileContents, pixmapToDataUrl
 
+from Globals import qVersionTuple
 from Utilities.AutoSaver import AutoSaver
 import Preferences
 
@@ -78,12 +79,24 @@ class NetworkManager(QNetworkAccessManager):
         self.authenticationRequired.connect(
             lambda reply, auth: self.authentication(reply.url(), auth))
         
+        if qVersionTuple() >= (5, 12, 0):
+            from PyQt5.QtWebEngineCore import QWebEngineUrlScheme
+            scheme = QWebEngineUrlScheme(b"eric")
+            scheme.setSyntax(QWebEngineUrlScheme.Syntax.Path)
+            scheme.setFlags(QWebEngineUrlScheme.SecureScheme)
+            QWebEngineUrlScheme.registerScheme(scheme)
         from .EricSchemeHandler import EricSchemeHandler
         self.__ericSchemeHandler = EricSchemeHandler()
         WebBrowserWindow.webProfile().installUrlSchemeHandler(
             QByteArray(b"eric"), self.__ericSchemeHandler)
         
         if engine:
+            if qVersionTuple() >= (5, 12, 0):
+                from PyQt5.QtWebEngineCore import QWebEngineUrlScheme
+                scheme = QWebEngineUrlScheme(b"qthelp")
+                scheme.setSyntax(QWebEngineUrlScheme.Syntax.Path)
+                scheme.setFlags(QWebEngineUrlScheme.SecureScheme)
+                QWebEngineUrlScheme.registerScheme(scheme)
             from .QtHelpSchemeHandler import QtHelpSchemeHandler
             self.__qtHelpSchemeHandler = QtHelpSchemeHandler(engine)
             WebBrowserWindow.webProfile().installUrlSchemeHandler(
@@ -132,6 +145,9 @@ class NetworkManager(QNetworkAccessManager):
         self.__loaded = False
         self.__temporarilyIgnoredSslErrors = {}
         self.__permanentlyIgnoredSslErrors = {}
+        
+        # set proxy factory to None to avoid crashes
+        QNetworkProxyFactory.setApplicationProxyFactory(None)
     
     def showSslErrorExceptionsDialog(self):
         """
