@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2009 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -12,8 +12,8 @@ from __future__ import unicode_literals
 import mimetypes
 import os
 
-from PyQt5.QtCore import pyqtSignal, QByteArray, QIODevice, QBuffer, QTimer, \
-    QMutex, QMutexLocker
+from PyQt5.QtCore import pyqtSignal, QByteArray, QIODevice, QBuffer, QMutex, \
+    QMutexLocker
 from PyQt5.QtWebEngineCore import QWebEngineUrlSchemeHandler, \
     QWebEngineUrlRequestJob
 
