@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2017 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2017 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -28,7 +28,8 @@ import Utilities
 import UI.PixmapCache
 
 from .SafeBrowsingAPIClient import SafeBrowsingAPIClient
-from .SafeBrowsingCache import SafeBrowsingCache, ThreatList, HashPrefixList
+from .SafeBrowsingCache import SafeBrowsingCache
+from .SafeBrowsingThreatList import ThreatList, HashPrefixList
 from .SafeBrowsingUrl import SafeBrowsingUrl
 from .SafeBrowsingUtilities import toHex
 
@@ -68,6 +69,7 @@ class SafeBrowsingManager(QObject):
         
         self.__gsbDialog = None
         self.__setPlatforms()
+        self.__setLookupMethod()
         
         self.__updatingThreatLists = False
         self.__threatListsUpdateTimer = QTimer(self)
@@ -95,6 +97,7 @@ class SafeBrowsingManager(QObject):
             bool(self.__apiKey))
         
         self.__setPlatforms()
+        self.__setLookupMethod()
         self.__setAutoUpdateThreatLists()
     
     def __setPlatforms(self):
@@ -112,6 +115,13 @@ class SafeBrowsingManager(QObject):
                 platform = "linux"
             self.__platforms = SafeBrowsingAPIClient.getPlatformTypes(platform)
     
+    def __setLookupMethod(self):
+        """
+        Private method to set the lookup method (Update API or Lookup API).
+        """
+        self.__useLookupApi = Preferences.getWebBrowser(
+            "SafeBrowsingUseLookupApi")
+    
     @classmethod
     def isEnabled(cls):
         """
@@ -169,7 +179,9 @@ class SafeBrowsingManager(QObject):
         """
         Private method to set auto update for the threat lists.
         """
-        autoUpdateEnabled = Preferences.getWebBrowser("SafeBrowsingAutoUpdate")
+        autoUpdateEnabled = \
+            Preferences.getWebBrowser("SafeBrowsingAutoUpdate") and \
+            not Preferences.getWebBrowser("SafeBrowsingUseLookupApi")
         if autoUpdateEnabled and self.isEnabled():
             nextUpdateDateTime = Preferences.getWebBrowser(
                 "SafeBrowsingUpdateDateTime")
@@ -246,9 +258,12 @@ class SafeBrowsingManager(QObject):
         
         # step 2: update threat lists
         threatListsForRemove = {}
-        for threatList, clientState in self.__cache.getThreatLists():
+        for threatList, _clientState in self.__cache.getThreatLists():
             threatListsForRemove[repr(threatList)] = threatList
-        threatLists = self.__apiClient.getThreatLists()
+        threatLists, error = self.__apiClient.getThreatLists()
+        if error:
+            return False, error
+        
         maximum = len(threatLists)
         current = 0
         self.progressMessage.emit(self.tr("Updating threat lists"), maximum)
@@ -280,8 +295,11 @@ class SafeBrowsingManager(QObject):
         clientStates = {}
         for threatList, clientState in threatLists:
             clientStates[threatList.asTuple()] = clientState
-        threatsUpdateResponses = \
+        threatsUpdateResponses, error = \
             self.__apiClient.getThreatsUpdate(clientStates)
+        if error:
+            return False, error
+        
         maximum = len(threatsUpdateResponses)
         current = 0
         self.progressMessage.emit(self.tr("Updating hash prefixes"), maximum)
@@ -367,25 +385,37 @@ class SafeBrowsingManager(QObject):
         
         @param url URL to be checked
         @type str or QUrl
-        @return list of threat lists the URL was found in
-        @rtype list of ThreatList
+        @return tuple containing the list of threat lists the URL was found in
+            and an error message
+        @rtype tuple of (list of ThreatList, str)
         @exception ValueError raised for an invalid URL
         """
         if self.isEnabled():
-            if isinstance(url, QUrl):
-                urlStr = url.toString().strip()
+            if self.__useLookupApi:
+                if isinstance(url, str):
+                    url = QUrl(url.strip())
+                
+                if url.isEmpty():
+                    raise ValueError("Empty URL given.")
+                
+                listNames, error = \
+                    self.__apiClient.lookupUrl(url, self.__platforms)
+                return listNames, error
             else:
-                urlStr = url.strip()
-            
-            if not urlStr:
-                raise ValueError("Empty URL given.")
-            
-            urlHashes = SafeBrowsingUrl(urlStr).hashes()
-            listNames = self.__lookupHashes(urlHashes)
-            if listNames:
-                return listNames
+                if isinstance(url, QUrl):
+                    urlStr = url.toString().strip()
+                else:
+                    urlStr = url.strip()
+                
+                if not urlStr:
+                    raise ValueError("Empty URL given.")
+                
+                urlHashes = SafeBrowsingUrl(urlStr).hashes()
+                listNames = self.__lookupHashes(urlHashes)
+                
+                return listNames, ""
         
-        return None
+        return None, ""
     
     def __lookupHashes(self, fullHashes):
         """
@@ -404,7 +434,7 @@ class SafeBrowsingManager(QObject):
         matchingFullHashes = set()
         isPotentialThreat = False
         # Lookup hash prefixes which match full URL hash
-        for threatList, hashPrefix, negativeCacheExpired in \
+        for _threatList, hashPrefix, negativeCacheExpired in \
                 self.__cache.lookupHashPrefix(cues):
             for fullHash in fullHashes:
                 if fullHash.startswith(hashPrefix):
@@ -486,7 +516,7 @@ class SafeBrowsingManager(QObject):
         negativeCacheDuration = int(
             fullHashResponses["negativeCacheDuration"].rstrip("s"))
         for prefixValue in hashPrefixes:
-            for threatList, clientState in threatLists:
+            for threatList, _clientState in threatLists:
                 self.__cache.updateHashPrefixExpiration(
                     threatList, prefixValue, negativeCacheDuration)
     
