@@ -347,8 +347,8 @@ class TabManagerWidget(QWidget):
         @type WebBrowserView
         """
         if view:
-            view.page().loadFinished.connect(self.delayedRefreshTree)
-            view.page().loadStarted.connect(self.delayedRefreshTree)
+            view.loadFinished.connect(self.delayedRefreshTree)
+            view.loadStarted.connect(self.delayedRefreshTree)
             view.titleChanged.connect(self.delayedRefreshTree)
             view.faviconChanged.connect(self.delayedRefreshTree)
     
