@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2010 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2010 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -444,6 +444,12 @@ class WebBrowserTabWidget(E5TabWidget):
             browser.page().recentlyAudibleChanged.connect(
                 lambda audible: self.__recentlyAudibleChanged(
                     audible, browser.page()))
+        try:
+            browser.page().printRequested.connect(
+                lambda: self.printBrowser(browser))
+        except AttributeError:
+            # pre Qt 5.12
+            pass
         
         if position == -1:
             index = self.addTab(browser, self.tr("..."))
@@ -1022,14 +1028,9 @@ class WebBrowserTabWidget(E5TabWidget):
                         """You have %n tab(s) open.""", "", self.count()),
                 modal=True,
                 parent=self)
-            if self.__mainWindow.fromEric:
-                quitButton = mb.addButton(
-                    self.tr("&Close"), E5MessageBox.AcceptRole)
-                quitButton.setIcon(UI.PixmapCache.getIcon("close.png"))
-            else:
-                quitButton = mb.addButton(
-                    self.tr("&Quit"), E5MessageBox.AcceptRole)
-                quitButton.setIcon(UI.PixmapCache.getIcon("exit.png"))
+            quitButton = mb.addButton(
+                self.tr("&Quit"), E5MessageBox.AcceptRole)
+            quitButton.setIcon(UI.PixmapCache.getIcon("exit.png"))
             closeTabButton = mb.addButton(
                 self.tr("C&lose Current Tab"), E5MessageBox.AcceptRole)
             closeTabButton.setIcon(UI.PixmapCache.getIcon("tabClose.png"))
