@@ -35,6 +35,8 @@ import os
 
 from Globals import qVersionTuple
 
+app = None
+
 
 if qVersionTuple() < (5, 6, 0):
     if "--quiet" not in sys.argv:
@@ -158,6 +160,8 @@ def main():
     """
     Main entry point into the application.
     """
+    global app
+    
     options = [
         ("--config=configDir",
          "use the given directory as the one containing the config files"),
