@@ -1,7 +1,7 @@
 #!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2006 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2006 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -37,16 +37,6 @@ for arg in sys.argv[:]:
                           settingsDir)
         sys.argv.remove(arg)
 
-from Globals import qVersionTuple
-if qVersionTuple() < (5, 6, 0):
-    WEBENGINE_AVAILABLE = False
-else:
-    try:
-        from PyQt5 import QtWebEngineWidgets    # __IGNORE_WARNING__
-        WEBENGINE_AVAILABLE = True
-    except ImportError:
-        WEBENGINE_AVAILABLE = False
-
 # make ThirdParty package available as a packages repository
 sys.path.insert(2, os.path.join(os.path.dirname(__file__),
                                 "ThirdParty", "Pygments"))
@@ -66,7 +56,7 @@ def createMainWidget(argv):
     @return reference to the main widget (QWidget)
     """
     from Preferences.ConfigurationDialog import ConfigurationWindow
-    w = ConfigurationWindow(webEngine=WEBENGINE_AVAILABLE)
+    w = ConfigurationWindow()
     w.show()
     w.showConfigurationPageByName("empty")
     return w
