@@ -1,7 +1,7 @@
 #!/usr/bin/env python2
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2017 - 2018 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2017 - 2019 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -13,6 +13,11 @@ of the ShellWindow module and starts the Qt event loop.
 
 from __future__ import unicode_literals
 
+import sys
+import os
+
+originalPathString = os.getenv("PATH")
+
 import Toolbox.PyQt4ImportHook  # __IGNORE_WARNING__
 
 try:  # Only for Py2
@@ -20,9 +25,6 @@ try:  # Only for Py2
 except (ImportError):
     pass
 
-import sys
-import os
-
 for arg in sys.argv[:]:
     if arg.startswith("--config="):
         import Globals
@@ -52,7 +54,7 @@ def createMainWidget(argv):
     """
     from QScintilla.ShellWindow import ShellWindow
     
-    return ShellWindow()
+    return ShellWindow(originalPathString)
 
 
 def main():
